/*
 * Ibis - IRCv3 Library
 * Copyright (C) 2022-2024 Ibis Developers
 *
 * Ibis is the legal property of its developers, whose names are too numerous
 * to list here.  Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, see <https://www.gnu.org/licenses/>.
 */

#if !defined(IBIS_GLOBAL_HEADER_INSIDE) && !defined(IBIS_COMPILATION)
# error "only <ibis.h> may be included directly"
#endif

#ifndef IBIS_CONSTANTS_H
#define IBIS_CONSTANTS_H

/**
 * IBIS_BATCH_CHATHISTORY:
 *
 * The constant string to use for the `chathistory` batch.
 *
 * See
 * [ircv3.net/specs/extension/chathistory](https://ircv3.net/specs/extensions/chathistory)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_BATCH_CHATHISTORY "chathistory" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_BATCH_LABELED_RESPONSE:
 *
 * The constant string to use for the `labeled-response` batch.
 *
 * See
 * [ircv3.net/specs/extensions/labeled-response](https://ircv3.net/specs/extensions/labeled-response)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_BATCH_LABELED_RESPONSE "labeled-response" \
	IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_BATCH_MULTILINE:
 *
 * The constant string to use for the `multiline` batch.
 *
 * See
 * [ircv3.net/specs/extensions/multiline](https://ircv3.net/specs/extensions/multiline)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_BATCH_MULTILINE "multiline" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_BATCH_NETJOIN:
 *
 * The constant string to use for the `netjoin` batch.
 *
 * See
 * [ircv3.net/specs/batches/netsplit](https://ircv3.net/specs/batches/netsplit)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_BATCH_NETJOIN "netjoin" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_BATCH_NETSPLIT:
 *
 * The constant string to use for the `netsplit` batch.
 *
 * See
 * [ircv3.net/specs/batches/netsplit](https://ircv3.net/specs/batches/netsplit)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_BATCH_NETSPLIT "netsplit" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_ACCOUNT_NOTIFY:
 *
 * The constant string to use when negotiating the `account-notify` capability.
 *
 * See
 * [ircv3.net/specs/extensions/account-notify](https://ircv3.net/specs/extensions/account-notify)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_ACCOUNT_NOTIFY "account-notify" \
	IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_ACCOUNT_REGISTRATION:
 *
 * The constant string to use when negotiating the `account-registration`
 * capability.
 *
 * See
 * [ircv3.net/specs/extensions/account-registration](https://ircv3.net/specs/extensions/account-registration)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_ACCOUNT_REGISTRATION "draft/account-registration" \
	IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_ACCOUNT_TAG:
 *
 * The constant string to use when negotiating the `account-tag` capability.
 *
 * See
 * [ircv3.net/specs/extensions/account-tag](https://ircv3.net/specs/extensions/account-tag)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_ACCOUNT_TAG "account-tag" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_AWAY_NOTIFY:
 *
 * The constant string to use when negotiating the `away-notify` capability.
 *
 * See
 * [ircv3.net/specs/extensions/away-notify](https://ircv3.net/specs/extensions/away-notify)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_AWAY_NOTIFY "away-notify" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_BATCH:
 *
 * The constant string to use when negotiating the `batch` capability.
 *
 * See
 * [ircv3.net/specs/extensions/batch](https://ircv3.net/specs/extensions/batch)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_BATCH "batch" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_CAP_LS_VERSION:
 *
 * The version to pass to the `CAP LS` command.
 *
 * See
 * [ircv3.net/specs/extensions/capability-negotiation](https://ircv3.net/specs/extensions/capability-negotiation)
 * for more information.
 *
 * Since: 0.1
 */
#define IBIS_CAPABILITY_CAP_LS_VERSION "302" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_CAPABILITY_CAP_NOTIFY:
 *
 * The constant string to use when negotiating the `cap-notify` capability.
 *
 * > Note: Ibis automatically requests and handles this capability.
 *
 * See
 * [ircv3.net/specs/extensions/capability-negotiation](https://ircv3.net/specs/extensions/capability-negotiation#cap-notify)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_CAP_NOTIFY "cap-notify" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_CHANNEL_RENAME:
 *
 * The constant string to use when negotiating the `channel-rename` capability.
 *
 * See
 * [ircv3.net/specs/extensions/channel-rename](https://ircv3.net/specs/extensions/channel-rename)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_CHANNEL_RENAME "draft/channel-rename" \
	IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_CHATHISTORY:
 *
 * The constant string to use when negotiating the `chathistory` capability.
 *
 * See
 * [ircv3.net/specs/extensions/chathistory](https://ircv3.net/specs/extensions/chathistory)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_CHATHISTORY "draft/chathistory" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_CHGHOST:
 *
 * The constant string to use when negotiating the `chghost` capability.
 *
 * See
 * [ircv3.net/specs/extensions/chghost](https://ircv3.net/specs/extensions/chghost)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_CHGHOST "chghost" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_ECHO_MESSAGE:
 *
 * The constant string to use when negotiating the `echo-message` capability.
 *
 * See
 * [ircv3.net/specs/extensions/echo-message](https://ircv3.net/specs/extensions/echo-message)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_ECHO_MESSAGE "echo-message" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_EVENT_PLAYBACK:
 *
 * The constant string to use when negotiating the `event-playback` capability.
 *
 * See
 * [ircv3.net/specs/extensions/chathistory](https://ircv3.net/specs/extensions/chathistory)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_EVENT_PLAYBACK "draft/event-playback" \
	IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_EXTENDED_JOIN:
 *
 * The constant string to use when negotiating the `extended-join` capability.
 *
 * See
 * [ircv3.net/specs/extensions/extended-join](https://ircv3.net/specs/extensions/extended-join)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_EXTENDED_JOIN "extended-join" \
	IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_EXTENDED_MONITOR:
 *
 * The constant string to use when negotiating the `extended-monitor`
 * capability.
 *
 * See
 * [ircv3.net/specs/extensions/extended-monitor](https://ircv3.net/specs/extensions/extended-monitor)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_EXTENDED_MONITOR "extended-monitor" \
	IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_INVITE_NOTIFY:
 *
 * The constant string to use when negotiating the `invite-notify` capability.
 *
 * See
 * [ircv3.net/specs/extensions/invite-notify](https://ircv3.net/specs/extensions/invite-notify)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_INVITE_NOTIFY "invite-notify" \
	IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_LABELED_RESPONSE:
 *
 * The constant string to use when negotiating the `labeled-response`
 * capability.
 *
 * See
 * [ircv3.net/specs/extensions/labeled-response](https://ircv3.net/specs/extensions/labeled-response)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_LABELED_RESPONSE "labeled-response" \
	IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_MESSAGE_TAGS:
 *
 * The constant string to use when negotiating the `message-tags` capability.
 *
 * > Note: Ibis automatically requests this capability and handles it via
 * [class@Tags].
 *
 * See
 * [ircv3.net/specs/extensions/message-tags](https://ircv3.net/specs/extensions/message-tags)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_MESSAGE_TAGS "message-tags" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_MONITOR:
 *
 * The constant string to use when negotiating the `monitor` capability.
 *
 * See
 * [ircv3.net/specs/extensions/monitor](https://ircv3.net/specs/extensions/monitor)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_MONITOR "monitor" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_MULTI_PREFIX:
 *
 * The constant string to use when negotiating the `multi-prefix` capability.
 *
 * See
 * [ircv3.net/specs/extensions/multi-prefix](https://ircv3.net/specs/extensions/multi-prefix)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_MULTI_PREFIX "multi-prefix" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_MULTILINE:
 *
 * The constant string to use when negotiating the `multiline` capability.
 *
 * See
 * [ircv3.net/specs/extensions/multiline](https://ircv3.net/specs/extensions/multiline)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_MULTILINE "draft/multiline" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_NO_IMPLICIT_NAMES:
 *
 * The constant string to use when negotiating the `no-implicit-names`
 * capability.
 *
 * See
 * [ircv3.net/specs/extensions/no-implicit-names](https://ircv3.net/specs/extensions/no-implicit-names)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_NO_IMPLICIT_NAMES "draft/no-implicit-names" \
	IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_PRE_AWAY:
 *
 * The constant string to use when negotiating the `pre-away` capability.
 *
 * See
 * [ircv3.net/specs/extensions/pre-away](https://ircv3.net/specs/extensions/pre-away)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_PRE_AWAY "draft/pre-away" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_READ_MARKER:
 *
 * The constant string to use when negotiating the `read-marker` capability.
 *
 * See
 * [ircv3.net/specs/extensions/read-marker](https://ircv3.net/specs/extensions/read-marker)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_READ_MARKER "draft/read-maker" \
	IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CAPABILITY_SASL:
 *
 * The constant string to use when negotiating the `sasl` capability.
 *
 * See
 * [ircv3.net/specs/extensions/sasl-3.1](https://ircv3.net/specs/extensions/sasl-3.1)
 * and
 * [ircv3.net/specs/extensions/sasl-3.2](https://ircv3.net/specs/extensions/sasl-3.2)
 * for more information.
 *
 * > Note: Ibis will automatically request this if you have set
 * [property@Client:hasl-context].
 *
 * Since: 0.1
 */
#define IBIS_CAPABILITY_SASL "sasl" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_CAPABILITY_SERVER_TIME:
 *
 * The constant string to use when negotiating the `server-time` capability.
 *
 * > Note: Ibis will automatically request this if
 * [const@CAPABILITY_MESSAGE_TAGS] is supported by the server.
 *
 * See
 * [ircv3.net/specs/extensions/server-time](https://ircv3.net/specs/extensions/server-time)
 * for more information.
 *
 * Since: 0.1
 */
#define IBIS_CAPABILITY_SERVER_TIME "server-time" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_CAPABILITY_SETNAME:
 *
 * The constant string to use when negotiating the `setname` capability.
 *
 * See
 * [ircv3.net/specs/extensions/setname](https://ircv3.net/specs/extensions/setname)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_SETNAME "setname" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_CAPABILITY_STANDARD_REPLIES:
 *
 * The constant string to use when negotiating the `standard-replies`
 * capability.
 *
 * See
 * [ircv3.net/specs/extensions/standard-replies](https://ircv3.net/specs/extensions/standard-replies)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_STANDARD_REPLIES "standard-replies" \
	IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_CAPABILITY_USERHOST_IN_NAMES:
 *
 * The constant string to use when negotiating the `userhost-in-names`
 * capability.
 *
 * See
 * [ircv3.net/specs/extensions/userhost-in-names](https://ircv3.net/specs/extensions/userhost-in-names)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CAPABILITY_USERHOST_IN_NAMES "userhost-in-names" \
	IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_CTCP_ACTION:
 *
 * A constant representing the CTCP `ACTION` command.
 *
 * See
 * [datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.1](https://datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.1)
 * for more information.
 *
 * Since: 0.1
 */
#define IBIS_CTCP_ACTION "ACTION" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_CTCP_DELIMITER:
 *
 * The delimiter used for CTCP messages.
 *
 * Since: 0.1
 */
#define IBIS_CTCP_DELIMITER 001 IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_CTCP_CLIENTINFO:
 *
 * A constant representing the CTCP `CLIENTINFO` command.
 *
 * See
 * [datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.2](https://datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.2)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CTCP_CLIENTINFO "CLIENTINFO" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CTCP_DCC:
 *
 * A constant representing the CTCP `DCC` command.
 *
 * See
 * [datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.3](https://datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.3)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CTCP_DCC "DCC" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CTCP_FINGER:
 *
 * A constant representing the CTCP `FINGER` command.
 *
 * See
 * [datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.4](https://datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.4)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CTCP_FINGER "FINGER" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CTCP_PING:
 *
 * A constant representing the CTCP `PING` command.
 *
 * See
 * [datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.5](https://datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.5)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CTCP_PING "PING" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CTCP_SOURCE:
 *
 * A constant representing the CTCP `SOURCE` command.
 *
 * See
 * [datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.6](https://datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.6)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CTCP_SOURCE "SOURCE" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CTCP_TIME:
 *
 * A constant representing the CTCP `TIME` command.
 *
 * See
 * [datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.7](https://datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.7)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CTCP_TIME "TIME" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_CTCP_USERINFO:
 *
 * A constant representing the CTCP `USERINFO` command.
 *
 * See
 * [datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.9](https://datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.9)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_CTCP_USERINFO "USERINFO" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_CTCP_VERSION:
 *
 * A constant representing the CTCP `VERSION` command.
 *
 * See
 * [datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.8](https://datatracker.ietf.org/doc/html/draft-oakley-irc-ctcp-02#appendix-A.8)
 * for more information.
 *
 * Since: 0.1
 */
#define IBIS_CTCP_VERSION "VERSION" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_ALREADYREGISTERED:
 *
 * A constant for the %ALREADYREGISTERED error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_ALREADYREGISTERED "462" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_BADCHANMASK:
 *
 * A constant for the %BADCHANMASK error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_BADCHANMASK "476" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_BADCHANNELKEY:
 *
 * A constant for the %BADCHANNELKEY error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_BADCHANNELKEY "475" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_BANNEDFROMCHAN:
 *
 * A constant for the %BANNEDFROMCHAN error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_BANNEDFROMCHAN "474" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_CANNOTSENDTOCHAN:
 *
 * A constant for the %CANNOTSENDTOCHAN error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_CANNOTSENDTOCHAN "404" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_CANTKILLSERVER:
 *
 * A constant for the %CANTKILLSERVER error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_CANTKILLSERVER "483" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_CHANNELISFULL:
 *
 * A constant for the %CHANNELISFULL error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_CHANNELISFULL "471" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_CHANOPRIVSNEEDED:
 *
 * A constant for the %CHANOPRIVSNEEDED error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_CHANOPRIVSNEEDED "482" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_ERRONEUSNICKNAME:
 *
 * A constant for the %ERRONEUSNICKNAME error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_ERRONEUSNICKNAME "432" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_HELPNOTFOUND:
 *
 * A constant for the %HELPNOTFOUND error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_HELPNOTFOUND "524" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_INPUTTOOLONG:
 *
 * A constant for the %INPUTTOOLONG error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_INPUTTOOLONG "417" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_INVALIDKEY:
 *
 * A constant for the %INVALIDKEY error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_INVALIDKEY "525" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_INVALIDMODEPARAM:
 *
 * A constant for the %INVALIDMODEPARAM error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_INVALIDMODEPARAM "696" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_INVITEONLYCHAN:
 *
 * A constant for the %INVITEONLYCHAN error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_INVITEONLYCHAN "473" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NEEDMOREPARAMS:
 *
 * A constant for the %NEEDMOREPARAMS error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NEEDMOREPARAMS "461" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NICKCOLLISION:
 *
 * A constant for the %NICKCOLLISION error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NICKCOLLISION "436" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NICKLOCKED:
 *
 * A constant for the %NICKLOCKED error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NICKLOCKED "902" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NICKNAMEINUSE:
 *
 * A constant for the %NICKNAMEINUSE error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NICKNAMEINUSE "433" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NOMOTD:
 *
 * A constant for the %NOMOTD error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NOMOTD "422" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NONICKNAMEGIVEN:
 *
 * A constant for the %NONICKNAMEGIVEN error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NONICKNAMEGIVEN "431" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NOOPERHOST:
 *
 * A constant for the %NOOPERHOST error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NOOPERHOST "491" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NOORIGIN:
 *
 * A constant for the %NOORIGIN error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NOORIGIN "409" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NOPRIVILEGES:
 *
 * A constant for the %NOPRIVILEGES error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NOPRIVILEGES "481" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NOPRIVS:
 *
 * A constant for the %NOPRIVS error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NOPRIVS "723" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NORECIPIENT:
 *
 * A constant for the %NORECIPIENT error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NORECIPIENT "411" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NOSUCHCHANNEL:
 *
 * A constant for the %NOSUCHCHANNEL error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NOSUCHCHANNEL "403" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NOSUCHNICK:
 *
 * A constant for the %NOSUCKNICK error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NOSUCHNICK "401" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NOSUCHSERVER:
 *
 * A constant for the %NOSUCHSERVER error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NOSUCHSERVER "402" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NOTEXTTOSEND:
 *
 * A constant for the %NOTEXTTOSEND error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NOTEXTTOSEND "412" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NOTONCHANNEL:
 *
 * A constant for the %NOTONCHANNEL error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NOTONCHANNEL "442" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_NOTREGISTERED:
 *
 * A constant for the %NOTREGISTERED error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_NOTREGISTERED "451" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_PASSWDMISMATCH:
 *
 * A constant for the %PASSWDMISMATCH error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_PASSWDMISMATCH "464" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_SASLABORTED:
 *
 * A constant for the %SASLABORTED error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_SASLABORTED "906" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_SASLALREADY:
 *
 * A constant for the %SASLALREADY error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_SASLALREADY "907" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_SASLFAIL:
 *
 * A constant for the %SASLFAIL error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_SASLFAIL "904" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_SASLTOOLONG:
 *
 * A constant for the %SASLTOOLONG error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_SASLTOOLONG "905" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_STARTTLS:
 *
 * A constant for the %STARTTLS error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_STARTTLS "691" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_TOOMANYCHANNELS:
 *
 * A constant for the %TOOMANYCHANNELS error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_TOOMANYCHANNELS "405" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_UMODEUNKNOWNFLAG:
 *
 * A constant for the %UMODEUNKNOWNFLAG error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_UMODEUNKNOWNFLAG "501" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_UNKNOWNCOMMAND:
 *
 * A constant for the %UNKNOWNCOMMAND error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_UNKNOWNCOMMAND "421" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_UNKNOWNERROR:
 *
 * A constant for the %UNKNOWNERROR error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_UNKNOWNERROR "400" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_UNKNOWNMODE:
 *
 * A constant for the %UNKNOWNMODE error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_UNKNOWNMODE "472" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_USERNOTINCHANNEL:
 *
 * A constant for the %USERNOTINCHANNEL error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_USERNOTINCHANNEL "441" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_USERONCHANNEL:
 *
 * A constant for the %USERONCHANNEL error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_USERONCHANNEL "443" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_USERSDONTMATCH:
 *
 * A constant for the %USERSDONTMATCH error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_USERSDONTMATCH "502" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_WASNOSUCHNICK:
 *
 * A constant for the %WASNOSUCHNICK error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_WASNOSUCHNICK "406" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_ERR_YOUREBANNEDCREEP:
 *
 * A constant for the %YOUREBANNEDCREEP error.
 *
 * Since: 0.1
 */
#define IBIS_ERR_YOUREBANNEDCREEP "465" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_FEATURE_AWAYLEN:
 *
 * A constant for the `AWAYLEN` feature.
 *
 * See
 * [modern.ircdocs.horse/#awaylen-parameter](https://modern.ircdocs.horse/#awaylen-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_AWAYLEN "AWAYLEN" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_CASEMAPPING:
 *
 * A constant for the `CASEMAPPING` feature.
 *
 * See
 * [modern.ircdocs.horse/#casemapping-parameter](https://modern.ircdocs.horse/#casemapping-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_CASEMAPPING "CASEMAPPING" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_CHANLIMIT:
 *
 * A constant for the `CHANLIMIT` feature.
 *
 * See
 * [modern.ircdocs.horse/#chanlimit-parameter](https://modern.ircdocs.horse/#chanlimit-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_CHANLIMIT "CHANLIMIT" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_CHANMODES:
 *
 * A constant for the `CHANMODES` feature.
 *
 * See
 * [modern.ircdocs.horse/#chanmodes-parameter](https://modern.ircdocs.horse/#chanmodes-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_CHANMODES "CHANMODES" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_CHANNELLEN:
 *
 * A constant for the `CHANNELLEN` feature.
 *
 * See
 * [modern.ircdocs.horse/#channellen-parameter](https://modern.ircdocs.horse/#channellen-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_CHANNELLEN "CHANNELLEN" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_CHANTYPES:
 *
 * A constant for the `CHANTYPES` feature.
 *
 * See
 * [modern.ircdocs.horse/#chantypes-parameter](https://modern.ircdocs.horse/#chantypes-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_CHANTYPES "CHANTYPES" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_CLIENTTAGDENY:
 *
 * A constant for the `CLIENTTAGDENY` feature.
 *
 * See
 * [ircv3.net/specs/extensions/message-tags#rpl_isupport-tokens](https://ircv3.net/specs/extensions/message-tags#rpl_isupport-tokens)
 * for more information.
 *
 * Since: 0.6
 */
#define IBIS_FEATURE_CLIENTTAGDENY "CLIENTTAGDENY" IBIS_AVAILABLE_MACRO_IN_0_6

/**
 * IBIS_FEATURE_ELIST:
 *
 * A constant for the `ELIST` feature.
 *
 * See
 * [modern.ircdocs.horse/#elist-parameter](https://modern.ircdocs.horse/#elist-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_ELIST "ELIST" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_EXCEPTS:
 *
 * A constant for the `EXCEPTS` feature.
 *
 * See
 * [modern.ircdocs.horse/#excepts-parameter](https://modern.ircdocs.horse/#excepts-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_EXCEPTS "EXCEPTS" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_EXTBAN:
 *
 * A constant for the `EXTBAN` feature.
 *
 * See
 * [modern.ircdocs.horse/#extban-parameter](https://modern.ircdocs.horse/#extban-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_EXTBAN "EXTBAN" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_HOSTLEN:
 *
 * A constant for the `HOSTLEN` feature.
 *
 * See
 * [modern.ircdocs.horse/#hostlen-parameter](https://modern.ircdocs.horse/#hostlen-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_HOSTLEN "HOSTLEN" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_INVEX:
 *
 * A constant for the `INVEX` feature.
 *
 * See
 * [modern.ircdocs.horse/#invex-parameter](https://modern.ircdocs.horse/#invex-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_INVEX "INVEX" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_KICKLEN:
 *
 * A constant for the `KICKLEN` feature.
 *
 * See
 * [modern.ircdocs.horse/#kicklen-parameter](https://modern.ircdocs.horse/#kicklen-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_KICKLEN "KICKLEN" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_MAXLIST:
 *
 * A constant for the `MAXLIST` feature.
 *
 * See
 * [modern.ircdocs.horse/#maxlist-parameter](https://modern.ircdocs.horse/#maxlist-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_MAXLIST "MAXLIST" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_MAXTARGETS:
 *
 * A constant for the `MAXTARGETS` feature.
 *
 * See
 * [modern.ircdocs.horse/#maxtargets-parameter](https://modern.ircdocs.horse/#maxtargets-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_MAXTARGETS "MAXTARGETS" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_MODES:
 *
 * A constant for the `MODES` feature.
 *
 * See
 * [modern.ircdocs.horse/#modes-parameter](https://modern.ircdocs.horse/#modes-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_MODES "MODES" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_NETWORK:
 *
 * A constant for the `NETWORK` feature.
 *
 * See
 * [modern.ircdocs.horse/#network-parameter](https://modern.ircdocs.horse/#network-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_NETWORK "NETWORK" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_NICKLEN:
 *
 * A constant for the `NICKLEN` feature.
 *
 * See
 * [modern.ircdocs.horse/#nicklen-parameter](https://modern.ircdocs.horse/#nicklen-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_NICKLEN "NICKLEN" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_PREFIX:
 *
 * A constant for the `PREFIX` feature.
 *
 * See
 * [modern.ircdocs.horse/#prefix-parameter](https://modern.ircdocs.horse/#prefix-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_PREFIX "PREFIX" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_PREFIX_MODES:
 *
 * A constant for the modes portion of [const@FEATURE_PREFIX].
 *
 * This is a synthetic feature that isn't part of any of the specifications.
 *
 * Since: 0.8
 */
#define IBIS_FEATURE_PREFIX_MODES "PREFIX-MODES" IBIS_AVAILABLE_MACRO_IN_0_8

/**
 * IBIS_FEATURE_PREFIX_PREFIXES:
 *
 * A constant for the prefixes portion of [const@FEATURE_PREFIX].
 *
 * This is a synthetic feature that isn't part of any of the specifications.
 *
 * Since: 0.8
 */
#define IBIS_FEATURE_PREFIX_PREFIXES "PREFIX-PREFIXES" IBIS_AVAILABLE_MACRO_IN_0_8

/**
 * IBIS_FEATURE_SAFELIST:
 *
 * A constant for the `SAFELIST` feature.
 *
 * See
 * [modern.ircdocs.horse/#safelist-parameter](https://modern.ircdocs.horse/#safelist-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_SAFELIST "SAFELIST" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_SILENCE:
 *
 * A constant for the `SILENCE` feature.
 *
 * See
 * [modern.ircdocs.horse/#silence-parameter](https://modern.ircdocs.horse/#silence-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_SILENCE "SILENCE" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_STATUSMSG:
 *
 * A constant for the `STATUSMSG` feature.
 *
 * See
 * [modern.ircdocs.horse/#statusmsg-parameter](https://modern.ircdocs.horse/#statusmsg-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_STATUSMSG "STATUSMSG" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_TARGMAX:
 *
 * A constant for the `TARGMAX` feature.
 *
 * See
 * [modern.ircdocs.horse/#targmax-parameter](https://modern.ircdocs.horse/#targmax-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_TARGMAX "TARGMAX" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_TOPICLEN:
 *
 * A constant for the `TOPICLEN` feature.
 *
 * See
 * [modern.ircdocs.horse/#topiclen-parameter](https://modern.ircdocs.horse/#topiclen-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_TOPICLEN "TOPICLEN" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_FEATURE_USERLEN:
 *
 * A constant for the `USERLEN` feature.
 *
 * See
 * [modern.ircdocs.horse/#userlen-parameter](https://modern.ircdocs.horse/#userlen-parameter)
 * for more information.
 *
 * Since: 0.3
 */
#define IBIS_FEATURE_USERLEN "USERLEN" IBIS_AVAILABLE_MACRO_IN_0_3

/**
 * IBIS_MSG_ADMIN:
 *
 * A constant for the %ADMIN message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_ADMIN "ADMIN" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_AUTHENTICATE:
 *
 * A constant for the %AUTHENTICATE message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_AUTHENTICATE "AUTHENTICATE" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_AWAY:
 *
 * A constant for the %AWAY message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_AWAY "AWAY" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_BATCH:
 *
 * A constant for the %BATCH message.
 *
 * See the [batch specification](https://ircv3.net/specs/extensions/batch) for
 * more information.
 *
 * Since: 0.12
 */
#define IBIS_MSG_BATCH "BATCH" IBIS_AVAILABLE_MACRO_IN_0_12

/**
 * IBIS_MSG_CAP:
 *
 * A constant for the %CAP message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_CAP "CAP" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_CONNECT:
 *
 * A constant for the %CONNECT message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_CONNECT "CONNECT" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_ERROR:
 *
 * A constant for the %ERROR message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_ERROR "ERROR" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_FAIL:
 *
 * A constant for the %FAIL standard reply message.
 *
 * See [standard replies](https://ircv3.net/specs/extensions/standard-replies)
 * for more information.
 *
 * Since: 0.8
 */
#define IBIS_MSG_FAIL "FAIL" IBIS_AVAILABLE_MACRO_IN_0_8

/**
 * IBIS_MSG_HELP:
 *
 * A constant for the %HELP message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_HELP "HELP" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_INFO:
 *
 * A constant for the %INFO message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_INFO "INFO" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_INVITE:
 *
 * A constant for the %INVITE message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_INVITE "INVITE" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_JOIN:
 *
 * A constant for the %JOIN message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_JOIN "JOIN" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_KICK:
 *
 * A constant for the %KICK message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_KICK "KICK" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_KILL:
 *
 * A constant for the %KILL message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_KILL "KILL" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_LINKS:
 *
 * A constant for the %LINKS message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_LINKS "LINKS" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_LIST:
 *
 * A constant for the %LIST message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_LIST "LIST" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_LUSERS:
 *
 * A constant for the %LUSERS message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_LUSERS "LUSERS" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_MODE:
 *
 * A constant for the %MODE message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_MODE "MODE" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_MOTD:
 *
 * A constant for the %MOTD message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_MOTD "MOTD" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_NAMES:
 *
 * A constant for the %NAMES message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_NAMES "NAMES" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_NICK:
 *
 * A constant for the %NICK message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_NICK "NICK" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_NOTE:
 *
 * A constant for the %NOTE standard reply message.
 *
 * See [standard replies](https://ircv3.net/specs/extensions/standard-replies)
 * for more information.
 *
 * Since: 0.8
 */
#define IBIS_MSG_NOTE "NOTE" IBIS_AVAILABLE_MACRO_IN_0_8

/**
 * IBIS_MSG_NOTICE:
 *
 * A constant for the %NOTICE message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_NOTICE "NOTICE" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_OPER:
 *
 * A constant for the %OPER message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_OPER "OPER" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_PART:
 *
 * A constant for the %PART message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_PART "PART" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_PASS:
 *
 * A constant for the %PASS message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_PASS "PASS" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_PING:
 *
 * A constant for the %PING message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_PING "PING" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_PONG:
 *
 * A constant for the %PONG message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_PONG "PONG" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_PRIVMSG:
 *
 * A constant for the %PRIVMSG message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_PRIVMSG "PRIVMSG" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_QUIT:
 *
 * A constant for the %QUIT message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_QUIT "QUIT" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_REHASH:
 *
 * A constant for the %REHASH message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_REHASH "REHASH" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_RESTART:
 *
 * A constant for the %RESTART message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_RESTART "RESTART" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_SQUIT:
 *
 * A constant for the %SQUIT message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_SQUIT "SQUIT" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_STATS:
 *
 * A constant for the %STATS message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_STATS "STATS" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_TAGMSG:
 *
 * A constant for the %TAGMSG message.
 *
 * More information can before in the
 * [here](https://ircv3.net/specs/extensions/message-tags#the-tagmsg-tag-only-message).
 *
 * Since: 0.5
 */
#define IBIS_MSG_TAGMSG "TAGMSG" IBIS_AVAILABLE_MACRO_IN_0_5

/**
 * IBIS_MSG_TIME:
 *
 * A constant for the %TIME message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_TIME "TIME" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_TOPIC:
 *
 * A constant for the %TOPIC message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_TOPIC "TOPIC" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_USER:
 *
 * A constant for the %USER message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_USER "USER" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_USERHOST:
 *
 * A constant for the %USERHOST message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_USERHOST "USERHOST" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_VERSION:
 *
 * A constant for the %VERSION message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_VERSION "VERSION" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_WALLOPS:
 *
 * A constant for the %WALLOPS message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_WALLOPS "WALLOPS" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_WARN:
 *
 * A constant for the %WARN standard reply message.
 *
 * See [standard replies](https://ircv3.net/specs/extensions/standard-replies)
 * for more information.
 *
 * Since: 0.8
 */
#define IBIS_MSG_WARN "WARN" IBIS_AVAILABLE_MACRO_IN_0_8

/**
 * IBIS_MSG_WHO:
 *
 * A constant for the %WHO message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_WHO "WHO" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_WHOIS:
 *
 * A constant for the %WHOIS message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_WHOIS "WHOIS" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_MSG_WHOWAS:
 *
 * A constant for the %WHOWAS message.
 *
 * Since: 0.1
 */
#define IBIS_MSG_WHOWAS "WHOWAS" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ADMINEMAIL:
 *
 * A constant for the %ADMINEMAIL reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ADMINEMAIL "259" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ADMINLOC1:
 *
 * A constant for the %ADMINLOC1 reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ADMINLOC1 "257" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ADMINLOC2:
 *
 * A constant for the %ADMINLOC2 reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ADMINLOC2 "258" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ADMINME:
 *
 * A constant for the %ADMINME reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ADMINME "256" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_AWAY:
 *
 * A constant for the %AWAY reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_AWAY "301" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_BANLIST:
 *
 * A constant for the %BANLIST reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_BANLIST "367" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_BOUNCE:
 *
 * A constant for the %BOUNCE reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_BOUNCE "010" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_CHANNELMODEIS:
 *
 * A constant for the %CHANNELMODEIS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_CHANNELMODEIS "324" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_CHANNEL_URL:
 *
 * A constant for the %CHANNEL_URL reply.
 *
 * This is an older reply. See
 * [defs.ircdocs.horse/defs/numerics](https://defs.ircdocs.horse/defs/numerics#rpl-channel-url-328)
 * for more information.
 *
 * Since: 0.9
 */
#define IBIS_RPL_CHANNEL_URL "328" IBIS_AVAILABLE_MACRO_IN_0_9

/**
 * IBIS_RPL_CREATED:
 *
 * A constant for the %CREATED reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_CREATED "003" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_CREATIONTIME:
 *
 * A constant for the %CREATIONTIME reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_CREATIONTIME "329" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ENDOFBANLIST:
 *
 * A constant for the %ENDOFBANLIST reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ENDOFBANLIST "368" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ENDOFEXCEPTLIST:
 *
 * A constant for the %ENDOFEXCEPTLIST reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ENDOFEXCEPTLIST "349" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ENDOFHELP:
 *
 * A constant for the %ENDOFHELP reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ENDOFHELP "706" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ENDOFINFO:
 *
 * A constant for the %ENDOFINFO reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ENDOFINFO "374" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ENDOFINVEXLIST:
 *
 * A constant for the %ENDOFINVEXLIST reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ENDOFINVEXLIST "347" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ENDOFINVITELIST:
 *
 * A constant for the %ENDOFINVITELIST reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ENDOFINVITELIST "337" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ENDOFLINKS:
 *
 * A constant for the %ENDOFLINKS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ENDOFLINKS "365" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ENDOFMOTD:
 *
 * A constant for the %ENDOFMOTD reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ENDOFMOTD "376" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ENDOFNAMES:
 *
 * A constant for the %ENDOFNAMES reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ENDOFNAMES "366" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ENDOFSTATS:
 *
 * A constant for the %ENDOFSTATS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ENDOFSTATS "219" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ENDOFWHO:
 *
 * A constant for the %ENDOFWHO reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ENDOFWHO "315" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ENDOFWHOIS:
 *
 * A constant for the %ENDOFWHOIS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ENDOFWHOIS "318" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ENDOFWHOWAS:
 *
 * A constant for the %ENDOFWHOWAS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ENDOFWHOWAS "369" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_EXCEPTLIST:
 *
 * A constant for the %EXCEPTLIST reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_EXCEPTLIST "348" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_GLOBALUSERS:
 *
 * A constant for the %GLOBALUSERS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_GLOBALUSERS "266" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_HELPSTART:
 *
 * A constant for the %HELPSTART reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_HELPSTART "704" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_HELPTXT:
 *
 * A constant for the %HELPTXT reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_HELPTXT "705" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_INFO:
 *
 * A constant for the %INFO reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_INFO "371" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_INVEXLIST:
 *
 * A constant for the %INVEXLIST reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_INVEXLIST "346" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_INVITELIST:
 *
 * A constant for the %INVITELIST reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_INVITELIST "336" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_INVITING:
 *
 * A constant for the %INVITING reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_INVITING "341" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_ISON:
 *
 * A constant for the %ISON reply.
 *
 * This is an older reply. See
 * [defs.ircdocs.horse/defs/numerics](https://defs.ircdocs.horse/defs/numerics#rpl-ison-303)
 * for more information.
 *
 * Since: 0.9
 */
#define IBIS_RPL_ISON "303" IBIS_AVAILABLE_MACRO_IN_0_9

/**
 * IBIS_RPL_ISUPPORT:
 *
 * A constant for the %ISUPPORT reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_ISUPPORT "005" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_LINKS:
 *
 * A constant for the %LINKS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_LINKS "364" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_LIST:
 *
 * A constant for the %LIST reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_LIST "322" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_LISTEND:
 *
 * A constant for the %LISTEND reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_LISTEND "323" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_LISTSTART:
 *
 * A constant for the %LISTSTART reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_LISTSTART "321" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_LOCALUSERS:
 *
 * A constant for the %LOCALUSERS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_LOCALUSERS "265" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_LOGGEDIN:
 *
 * A constant for the %LOGGEDIN reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_LOGGEDIN "900" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_LOGGEDOUT:
 *
 * A constant for the %LOGGEDOUT reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_LOGGEDOUT "901" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_LUSERCHANNELS:
 *
 * A constant for the %LUSERCHANNELS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_LUSERCHANNELS "254" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_LUSERCLIENT:
 *
 * A constant for the %LUSERCLIENT reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_LUSERCLIENT "251" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_LUSERME:
 *
 * A constant for the %LUSERME reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_LUSERME "255" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_LUSEROP:
 *
 * A constant for the %LUSEROP reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_LUSEROP "252" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_LUSERUNKNOWN:
 *
 * A constant for the %LUSERUNKNOWN reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_LUSERUNKNOWN "253" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_MYINFO:
 *
 * A constant for the %MYINFO reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_MYINFO "004" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_MOTD:
 *
 * A constant for the %MOTD reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_MOTD "372" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_MOTDSTART:
 *
 * A constant for the %MOTDSTART reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_MOTDSTART "375" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_NAMREPLY:
 *
 * A constant for the %NAMREPLY reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_NAMREPLY "353" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_NONE:
 *
 * A constant for the %NONE reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_NONE "300" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_NOTOPIC:
 *
 * A constant for the %NOTOPIC reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_NOTOPIC "331" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_NOWAWAY:
 *
 * A constant for the %NOWAWAY reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_NOWAWAY "306" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_REHASHING:
 *
 * A constant for the %REHASHING reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_REHASHING "382" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_SASLMECHS:
 *
 * A constant for the %SASLMECHS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_SASLMECHS "908" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_SASLSUCCESS:
 *
 * A constant for the %SASLSUCCESS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_SASLSUCCESS "903" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_STARTTLS:
 *
 * A constant for the %STARTTLS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_STARTTLS "670" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_STATSCOMMANDS:
 *
 * A constant for the %STATSCOMMANDS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_STATSCOMMANDS "212" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_STATSCONN:
 *
 * A constant for the %STATSCONN reply.
 *
 * This is an older reply. See
 * [defs.ircdocs.horse/defs/numerics](https://defs.ircdocs.horse/defs/numerics#rpl-statsconn-250)
 * for more information.
 *
 * Since: 0.9
 */
#define IBIS_RPL_STATSCONN "250" IBIS_AVAILABLE_MACRO_IN_0_9

/**
 * IBIS_RPL_STATSUPTIME:
 *
 * A constant for the %STATSUPTIME reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_STATSUPTIME "242" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_TIME:
 *
 * A constant for the %TIME reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_TIME "391" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_TOPIC:
 *
 * A constant for the %TOPIC reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_TOPIC "332" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_TOPICWHOTIME:
 *
 * A constant for the %TOPICWHOTIME reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_TOPICWHOTIME "333" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_TRYAGAIN:
 *
 * A constant for the %TRYAGAIN reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_TRYAGAIN "263" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_UMODEIS:
 *
 * A constant for the %UMODEIS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_UMODEIS "221" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_UNAWAY:
 *
 * A constant for the %UNAWAY reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_UNAWAY "305" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_USERHOST:
 *
 * A constant for the %USERHOST reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_USERHOST "302" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_VERSION:
 *
 * A constant for the %VERSION reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_VERSION "351" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WELCOME:
 *
 * A constant for the %WELCOME reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WELCOME "001" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOISACCOUNT:
 *
 * A constant for the %WHOISACCOUNT reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOISACCOUNT "330" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOISACTUALLY:
 *
 * A constant for the %WHOISACTUALLY reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOISACTUALLY "338" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOISCERTFP:
 *
 * A constant for the %WHOISCERTFP reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOISCERTFP "276" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOISCHANNELS:
 *
 * A constant for the %WHOISCHANNELS reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOISCHANNELS "319" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOISHOST:
 *
 * A constant for the %WHOISIDLE reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOISHOST "378" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOISIDLE:
 *
 * A constant for the %WHOISIDLE reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOISIDLE "317" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOISMODES:
 *
 * A constant for the %WHOISMODES reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOISMODES "379" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOISOPERATOR:
 *
 * A constant for the %WHOISOPERATOR reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOISOPERATOR "313" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOISREGNICK:
 *
 * A constant for the %WHOISREGNICK reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOISREGNICK "307" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOISSECURE:
 *
 * A constant for the %WHOISSECURE reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOISSECURE "671" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOISSERVER:
 *
 * A constant for the %WHOISSERVER reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOISSERVER "312" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOISSPECIAL:
 *
 * A constant for the %WHOISSPECIAL reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOISSPECIAL "320" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOISUSER:
 *
 * A constant for the %WHOISUSER reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOISUSER "311" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOREPLY:
 *
 * A constant for the %WHOREPLY reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOREPLY "352" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_WHOWASUSER:
 *
 * A constant for the %WHOWASUSER reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_WHOWASUSER "314" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_YOURHOST:
 *
 * A constant for the %YOURHOST reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_YOURHOST "002" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_RPL_YOUREOPER:
 *
 * A constant for the %YOUREOPER reply.
 *
 * Since: 0.1
 */
#define IBIS_RPL_YOUREOPER "381" IBIS_AVAILABLE_MACRO_IN_0_1

/**
 * IBIS_STANDARD_REPLY_TYPE_FAIL:
 *
 * A constant for the `FAIL` standard reply type.
 *
 * See [standard replies message
 * format](https://ircv3.net/specs/extensions/standard-replies#message-format)
 * for more information.
 *
 * Since: 0.8
 */
#define IBIS_STANDARD_REPLY_TYPE_FAIL "FAIL" IBIS_AVAILABLE_MACRO_IN_0_8

/**
 * IBIS_STANDARD_REPLY_TYPE_NOTE:
 *
 * A constant for the `NOTE` standard reply type.
 *
 * See [standard replies message
 * format](https://ircv3.net/specs/extensions/standard-replies#message-format)
 * for more information.
 *
 * Since: 0.8
 */
#define IBIS_STANDARD_REPLY_TYPE_NOTE "NOTE" IBIS_AVAILABLE_MACRO_IN_0_8

/**
 * IBIS_STANDARD_REPLY_TYPE_WARN:
 *
 * A constant for the `WARN` standard reply type.
 *
 * See [standard replies message
 * format](https://ircv3.net/specs/extensions/standard-replies#message-format)
 * for more information.
 *
 * Since: 0.8
 */
#define IBIS_STANDARD_REPLY_TYPE_WARN "WARN" IBIS_AVAILABLE_MACRO_IN_0_8

/**
 * IBIS_TAG_ACCOUNT:
 *
 * A constant for the `account` tag.
 *
 * See
 * [ircv3.net/specs/extensions/account-tag](https://ircv3.net/specs/extensions/account-tag)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_TAG_ACCOUNT "account" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_TAG_BATCH:
 *
 * A constant for the `batch` tag.
 *
 * See
 * [ircv3.net/specs/extensions/batch](https://ircv3.net/specs/extensions/batch)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_TAG_BATCH "batch" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_TAG_BOT:
 *
 * A constant for the `bot` tag.
 *
 * See
 * [ircv3.net/specs/extensions/bot-mode](https://ircv3.net/specs/extensions/bot-mode)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_TAG_BOT "bot" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_TAG_LABEL:
 *
 * A constant for the `label` tag.
 *
 * See
 * [ircv3.net/specs/extensions/labeled-response](https://ircv3.net/specs/extensions/labeled-response)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_TAG_LABEL "label" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_TAG_MSGID:
 *
 * A constant for the `msgid` tag.
 *
 * See
 * [ircv3.net/specs/extensions/message-ids](https://ircv3.net/specs/extensions/message-ids)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_TAG_MSGID "msgid" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_TAG_MULTILINE_CONCAT:
 *
 * A constant for the `multiline-concat` tag.
 *
 * See
 * [ircv3.net/specs/extensions/multiline](https://ircv3.net/specs/extensions/multiline)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_TAG_MULTILINE_CONCAT "draft/multiline-concat" \
	IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_TAG_TIME:
 *
 * A constant for the `time` tag.
 *
 * See
 * [ircv3.net/specs/extensions/server-time](https://ircv3.net/specs/extensions/server-time)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_TAG_TIME "time" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_TAG_REACT:
 *
 * A constant for the `+react` tag.
 *
 * See
 * [ircv3.net/specs/client-tags/react](https://ircv3.net/specs/client-tags/react)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_TAG_REACT "+draft/react" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_TAG_REPLY:
 *
 * A constant for the `+reply` tag.
 *
 * See
 * [ircv3.net/specs/client-tags/reply](https://ircv3.net/specs/client-tags/reply)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_TAG_REPLY "+draft/reply" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_TAG_TYPING:
 *
 * A constant for the `typing` tag.
 *
 * See
 * [ircv3.net/specs/client-tags/typing](https://ircv3.net/specs/client-tags/typing)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_TAG_TYPING "+typing" IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_TAG_CHANNEL_CONTEXT:
 *
 * A constant for the `+channel-context` tag.
 *
 * See
 * [ircv3.net/specs/client-tags/channel-context](https://ircv3.net/specs/client-tags/channel-context)
 * for more information.
 *
 * Since: 0.2
 */
#define IBIS_TAG_CHANNEL_CONTEXT "+draft/channel-context" \
	IBIS_AVAILABLE_MACRO_IN_0_2

/**
 * IBIS_TYPING_ACTIVE:
 *
 * A constant for the `active` value of typing client tag.
 *
 * See the [typing specification](https://ircv3.net/specs/client-tags/typing)
 * for more information.
 *
 * Since: 0.5
 */
#define IBIS_TYPING_ACTIVE "active" IBIS_AVAILABLE_MACRO_IN_0_5

/**
 * IBIS_TYPING_PAUSED:
 *
 * A constant for the `paused` value of the typing client tag.
 *
 * See the [typing specification](https://ircv3.net/specs/client-tags/typing)
 * for more information.
 *
 * Since: 0.5
 */
#define IBIS_TYPING_PAUSED "paused" IBIS_AVAILABLE_MACRO_IN_0_5

/**
 * IBIS_TYPING_DONE:
 *
 * A constant for the `done` value of the typing client tag.
 *
 * See the [typing specification](https://ircv3.net/specs/client-tags/typing)
 * for more information.
 *
 * Since: 0.5
 */
#define IBIS_TYPING_DONE "done" IBIS_AVAILABLE_MACRO_IN_0_5

#endif /* IBIS_CONSTANTS_H */
